@@ -1,5 +1,5 @@
 #! /bin/sh
-# $PostgreSQL: pgsql/src/test/regress/pg_regress.sh,v 1.53.4.1 2005/07/17 18:29:13 tgl Exp $
+# $PostgreSQL: pgsql/src/test/regress/pg_regress.sh,v 1.53.4.4 2006/10/09 01:45:49 tgl Exp $
 
 me=`basename $0`
 : ${TMPDIR=/tmp}
@@ -21,6 +21,7 @@ Options:
   --schedule=FILE           use test ordering schedule from FILE
                             (may be used multiple times to concatenate)
   --temp-install[=DIR]      create a temporary installation (in DIR)
+  --no-locale               use C locale
 
 Options for \`temp-install' mode:
   --top-builddir=DIR        (relative) path to top level build directory
@@ -97,6 +98,7 @@ fi
 unset mode
 unset schedule
 unset debug
+unset nolocale
 unset top_builddir
 unset temp_install
 unset multibyte
@@ -131,6 +133,9 @@ do
         --multibyte=*)
                 multibyte=`expr "x$1" : "x--multibyte=\(.*\)"`
                 shift;;
+        --no-locale)
+                nolocale=yes
+                shift;;
         --temp-install)
                 temp_install=./tmp_check
                 shift;;
@@ -408,7 +413,8 @@ then
     rm $backup
 
     message "initializing database system"
-    [ "$debug" = yes ] && initdb_options='--debug'
+    [ "$debug" = yes ] && initdb_options="--debug"
+    [ "$nolocale" = yes ] && initdb_options="$initdb_options --no-locale"
     "$bindir/initdb" -D "$PGDATA" -L "$datadir" --noclean $initdb_options >"$LOGDIR/initdb.log" 2>&1
 
     if [ $? -ne 0 ]
@@ -430,7 +436,7 @@ then
     if [ "$unix_sockets" = no ]; then
         postmaster_options="$postmaster_options -c listen_addresses=$hostname"
     else
-        postmaster_options="$postmaster_options -c listen_addresses=''"
+        postmaster_options="$postmaster_options -c listen_addresses="
     fi
     "$bindir/postmaster" -D "$PGDATA" -F $postmaster_options >"$LOGDIR/postmaster.log" 2>&1 &
     postmaster_pid=$!
@@ -674,7 +680,8 @@ do
         # to a system-specific expected file.
         # There shouldn't be multiple matches, but take the last if there are.
 
-        EXPECTED="$inputdir/expected/${name}"
+        STDEXPECTED="$inputdir/expected/${name}"
+        EXPECTED="$STDEXPECTED"
         for LINE in $SUBSTLIST
         do
             if [ `expr "$LINE" : "$name="` -ne 0 ]
@@ -684,13 +691,14 @@ do
             fi
         done
 
-        # If there are multiple equally valid result files, loop to get the right one.
+        # If there are multiple equally valid result files,
+        # loop to get the right one.
         # If none match, diff against the closest one.
 
         bestfile=
         bestdiff=
         result=2
-        for thisfile in $EXPECTED.out ${EXPECTED}_[0-9].out; do
+        for thisfile in $EXPECTED.out ${EXPECTED}_[0-9].out $STDEXPECTED.out; do
             [ ! -r "$thisfile" ] && continue
             diff $DIFFFLAGS $thisfile $outputdir/results/${name}.out >/dev/null 2>&1
             result=$?
